@@ -1,3 +1,6 @@
+from typing import Tuple, Optional
+
+import Xlib
 from ewmh import EWMH
 
 from gui_util.window import Window
@@ -15,6 +18,3 @@ def get_current_window():
     xlib_win = wm.getActiveWindow()
     window = Window.from_xlib_window(xlib_win)
     return window
-
-
-
